summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_setup_pbuilder.sh
diff options
context:
space:
mode:
Diffstat (limited to 'bin/reproducible_setup_pbuilder.sh')
-rwxr-xr-xbin/reproducible_setup_pbuilder.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_setup_pbuilder.sh b/bin/reproducible_setup_pbuilder.sh
index c64e2fa9..43943d5c 100755
--- a/bin/reproducible_setup_pbuilder.sh
+++ b/bin/reproducible_setup_pbuilder.sh
@@ -127,8 +127,8 @@ setup_pbuilder() {
sudo pbuilder --execute $pbuilder_http_proxy --save-after-exec --basetgz /var/cache/pbuilder/${NAME}-new.tgz -- ${TMPFILE} | tee ${LOG}
rm ${TMPFILE}
- # add repo only for experimental and sid - keep stretch "real" (and sid progressive!)
- if [ "$SUITE" != "stretch" ] ; then
+ # add repo only for experimental and unstable - keep stretch/buster "real" (and sid progressive!)
+ if [ "$SUITE" = "unstable" ] || [ "$SUITE" = "experimental" ]; then
# apply further customisations, eg. install $PACKAGES from our repo
create_setup_our_repo_tmpfile ${TMPFILE} "${PACKAGES}"
if [ "$DEBUG" = "true" ] ; then